From a793747d92d9b1d93153c7fb4e0c82fe90624c78 Mon Sep 17 00:00:00 2001
From: est31 <MTest31@outlook.com>
Date: Thu, 18 Jun 2015 04:16:47 +0200
Subject: [PATCH] Move coal furnaces to other/

---
 technic/items.lua |   14 +++++---------
 1 files changed, 5 insertions(+), 9 deletions(-)

diff --git a/technic/items.lua b/technic/items.lua
index 3c00dd9..27e05e4 100644
--- a/technic/items.lua
+++ b/technic/items.lua
@@ -100,10 +100,6 @@
 	inventory_image = "technic_lv_transformer.png",
 })
 
-minetest.register_craftitem("technic:lv_transformer", {
-	description = S("Low Voltage Transformer"),
-	inventory_image = "technic_lv_transformer.png",
-})
 minetest.register_craftitem("technic:mv_transformer", {
 	description = S("Medium Voltage Transformer"),
 	inventory_image = "technic_mv_transformer.png",
@@ -197,15 +193,15 @@
 	-- linear interpolation of activity along that scale, rooted at
 	-- a natural (0.7%-fissile) uranium block having the activity of
 	-- 9 uranium ore blocks (due to 9 ingots per block).  The group
 	-- value is proportional to the square root of the activity,
 	-- and uranium ore has radioactive=1.  This yields radioactive=2
 	-- for a fully-depleted uranium block and radioactive=5 for a
 	-- 3.5%-fissile uranium block.
 	(ov or minetest.register_node)(block, {
 		description = string.format(S("%.1f%%-Fissile Uranium Block"), p/10),
 		tiles = {"technic_uranium_block.png"},
 		is_ground_content = true,
-		groups = {uranium_block=1, not_in_creative_inventory=nici, cracky=1, level=2, radioactive=math.floor(math.sqrt((1+5.55*p/35) * 9 / (1+5.55*7/35)) + 0.5)},
+		groups = {uranium_block=1, not_in_creative_inventory=nici, cracky=1, level=2, radioactive=math.floor(1000*math.sqrt((1+5.55*p/35) * 9 / (1+5.55*7/35)) + 0.5)},
 		sounds = default.node_sound_stone_defaults(),
 	});
 	if not ov then
@@ -197,15 +193,15 @@
 	-- a natural (0.7%-fissile) uranium block having the activity of
 	-- 9 uranium ore blocks (due to 9 ingots per block).  The group
-	-- value is proportional to the square root of the activity,
-	-- and uranium ore has radioactive=1.  This yields radioactive=2
-	-- for a fully-depleted uranium block and radioactive=5 for a
-	-- 3.5%-fissile uranium block.
+	-- value is proportional to the square root of the activity, and
+	-- uranium ore has radioactive=1000.  This yields radioactive=2065
+	-- for a fully-depleted uranium block and radioactive=5286 for
+	-- a 3.5%-fissile uranium block.
 	(ov or minetest.register_node)(block, {
 		description = string.format(S("%.1f%%-Fissile Uranium Block"), p/10),

--
Gitblit v1.8.0